#!/bin/sh
#
# complete ProSynth to HL and WAV via PROCSY
#
# run with argument = XML filename
# need .xml, .x, and .lab files in directory:
#	.xml has UTT, FILE & TOKEN
#	.lab has the phonetic annotation
#	.x has the formant and fundamental frequency data from ESPS
#
# base directory
PROCSY=c:/cygwin/home/mark/prosynth/procsy2005
#
# check arguments
if test $# -lt 4 
then
    echo "usage  : procsy-full.sh synthname labelfile formantfile token-string"
    echo "example: procsy-full.sh jh0001 jh0001.lab jh0001.x \"it's a \\\`lie\""
    exit
fi
#
# get base name
f=`echo $1 | sed s/.xml//` 
#
# make a basic PROSYNTH utterance
$PROCSY/bin/uttmake -l "$2" -x "$3" -t "$4" $f.xml
#
# load in annotations
$PROCSY/bin/prx $PROCSY/prx/ldlabels.prx $f.xml >$f.1
#
# load in formant data
$PROCSY/bin/prx $PROCSY/prx/ldspdata.prx $f.1 >$f.2
#
# provide dictionary pronunciations
$PROCSY/bin/uttdict2 $f.2 >$f.3
#
# compose phonological structure
$PROCSY/bin/uttcomp2 $f.3 >$f.4
#
# align structure to annotations
$PROCSY/bin/uttalign $f.4 >$f.5
#
# run procsy
$PROCSY/bin/prx $PROCSY/prx/procsy.prx $f.5 >$f-full.xml
#
# convert to HL
$PROCSY/bin/prx -n $PROCSY/prx/xml2hl.prx $f-full.xml >$f.hl
#
# convert to WAV
$PROCSY/bin/hlsyn -o $f-out.wav $f.hl
#
# tidy up
rm $f.1 $f.2 $f.3 $f.4 $f.5
