#!/bin/sh
#
# complete ProSynth to HL and WAV via PROCSY
#
# run with arguments = basename file.wav file.lab tokenstring
# inputs:
#	file.wav has the original audio recording
#	file.lab has the phonetic annotations in ESPS format
#	tokenstring is the word sequence with stress markers
# outputs:
#	basename.xml is processed XML file
#	basename.hl is HLSYN input file
#	basename-out.wav is HLSYN audio output
#
#
# base directory
PROCSY=c:/cygwin/home/mark/prosynth/procsy2005
#
# check arguments
if test $# -lt 4 
then
    echo "usage  : procsy-wav.sh synthname wavfile labelfile token-string"
    echo "example: procsy-wav.sh jh0001 jh0001.wav jh0001.lab \"it's a \\\`lie\""
    exit
fi
#
# get base name
f=`echo $1 | sed s/.xml//` 
#
# process audio (using SFS programs)
$PROCSY/bin/hed -n $f.sfs
$PROCSY/bin/remove -e $f.sfs
$PROCSY/bin/slink -isp -tWAV $2 $f.sfs
$PROCSY/bin/fxrapt $f.sfs
$PROCSY/bin/formanal $f.sfs
$PROCSY/bin/envelope -w 0.05 -d $f.sfs
$PROCSY/bin/sml $PROCSY/prx/sfs2x.sml $f.sfs >$f.sx
#
# make a basic PROSYNTH utterance
$PROCSY/bin/uttmake -l "$3" -x "$f.sx" -t "$4" $f.xml
#
# load in annotations
$PROCSY/bin/prx $PROCSY/prx/ldlabels.prx $f.xml >$f.1
#
# load in formant data
$PROCSY/bin/prx $PROCSY/prx/ldspdata.prx $f.1 >$f.2
#
# provide dictionary pronunciations
$PROCSY/bin/uttdict2 $f.2 >$f.3
#
# compose phonological structure
$PROCSY/bin/uttcomp2 $f.3 >$f.4
#
# align structure to annotations
$PROCSY/bin/uttalign $f.4 >$f.5
#
# run procsy
$PROCSY/bin/prx $PROCSY/prx/procsy.prx $f.5 >$f.xml
#
# convert to HL
$PROCSY/bin/prx -n $PROCSY/prx/xml2hl.prx $f.xml >$f.hl
#
# convert to WAV
$PROCSY/bin/hlsyn -o $f-out.wav $f.hl
#
# tidy up
rm -f $f.1 $f.2 $f.3 $f.4 $f.5 $f.sx $f.sfs $f.bak
